package com.admin.major.mapper;

import java.util.List;
import com.admin.major.domain.DataFile;

/**
 * 数据归档Mapper接口
 * 
 * @author ljx
 * @date 2022-06-24
 */
public interface DataFileMapper 
{
    /**
     * 查询数据归档
     * 
     * @param dataFileId 数据归档主键
     * @return 数据归档
     */
    public DataFile selectDataFileByDataFileId(Long dataFileId);

    /**
     * 查询数据归档列表
     * 
     * @param dataFile 数据归档
     * @return 数据归档集合
     */
    public List<DataFile> selectDataFileList(DataFile dataFile);

    /**
     * 新增数据归档
     * 
     * @param dataFile 数据归档
     * @return 结果
     */
    public int insertDataFile(DataFile dataFile);

    /**
     * 修改数据归档
     * 
     * @param dataFile 数据归档
     * @return 结果
     */
    public int updateDataFile(DataFile dataFile);

    /**
     * 删除数据归档
     * 
     * @param dataFileId 数据归档主键
     * @return 结果
     */
    public int deleteDataFileByDataFileId(Long dataFileId);

    /**
     * 批量删除数据归档
     * 
     * @param dataFileIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDataFileByDataFileIds(Long[] dataFileIds);
}
